#!/usr/bin/python
# -*- coding: Utf-8 -*-	

# Script qui sert à copier ...
#
# locale/en_EN/LC_MESSAGES/ekd.mo et locale/en_EN/LC_MESSAGES/ekdDoc.mo vers 
# (par exemple) locale/en_AU/LC_MESSAGES/ekd.mo locale/en_AU/LC_MESSAGES/ekd.mo 
# (et ce pour tous les répertoires symbole langue dont la langue officielle est l'anglais)
#
# puis ...
#
# locale/es_ES/LC_MESSAGES/ekd.mo et locale/es_ES/LC_MESSAGES/ekdDoc.mo vers 
# (par exemple) locale/es_AR/LC_MESSAGES/ekd.mo locale/es_AR/LC_MESSAGES/ekd.mo 
# (et ce pour tous les répertoires symbole langue dont la langue officielle est l'espagnol).
#
# ATTENTION (!!!): les répertoires (et sous-répertoires):
#
# locale/en_EN/LC_MESSAGES et locale/es_ES/LC_MESSAGES
#
# ... ne doivent jamais être éliminés.
#
# Les nationalités et communautés gérées pour l'instant sont:
#
# pour l'anglais (autres que 'en_EN' ==> English):
#
# 'en_AU' => 'English (Australia)', 'en_CA' => 'English (Canada)', 'en_GB' => 'English (United Kingdom)',
# 'en_HK' => 'English (Hong Kong SAR China)', 'en_IE' => 'English (Ireland)', 'en_IN' => 'English (India)',
# 'en_JM' => 'English (Jamaica)', 'en_LR' => 'English (Liberia)', 'en_NZ' => 'English (New Zealand)',
# 'en_PH' => 'English (Philippines)', 'en_SG' => 'English (Singapore)', 'en_TT' => 'English (Trinidad and Tobago)',
# 'en_US' => 'English (United States)', 'en_ZA' => 'English (South Africa)'.
#
# pour l'espagnol (autres que 'es_ES' => Spanish):
#
# 'es_AR' => 'Spanish (Argentina)', 'es_BO' => 'Spanish (Bolivia)', 'es_CA' => 'Spanish (Canada)', 
# 'es_CL' => 'Spanish (Chile)', 'es_CO' => 'Spanish (Colombia)', 'es_CR' => 'Spanish (Costa Rica)', 
# 'es_CU' => 'Spanish (Cuba)', 'es_DO' => 'Spanish (Dominican Republic)', 'es_EC' => 'Spanish (Ecuador)', 
# 'es_GQ' => 'Spanish (Equatorial Guinea)', 'es_GT' => 'Spanish (Guatemala)', 'es_HN' => 'Spanish (Honduras)', 
# 'es_MX' => 'Spanish (Mexico)', 'es_NI' => 'Spanish (Nicaragua)', 'es_PA' => 'Spanish (Panama)', 
# 'es_PE' => 'Spanish (Peru)', 'es_PR' => 'Spanish (Puerto Rico)', 'es_PY' => 'Spanish (Paraguay)', 
# 'es_SV' => 'Spanish (El Salvador)', 'es_US' => 'Spanish (United States)', 'es_UY' => 'Spanish (Uruguay)', 
# 'es_VE' => 'Spanish (Venezuela)'.


import os, glob, shutil


# On liste tous les chemins possibles des nationalités (ou communautés) de langue anglaise et espagnole
ChemSymbLang_EN_ES = ['locale/en_AU/LC_MESSAGES', 'locale/en_CA/LC_MESSAGES', 'locale/en_GB/LC_MESSAGES', 'locale/en_HK/LC_MESSAGES', 'locale/en_IE/LC_MESSAGES', 'locale/en_IN/LC_MESSAGES', 'locale/en_JM/LC_MESSAGES', 'locale/en_LR/LC_MESSAGES', 'locale/en_NZ/LC_MESSAGES', 'locale/en_PH/LC_MESSAGES', 'locale/en_SG/LC_MESSAGES', 'locale/en_TT/LC_MESSAGES', 'locale/en_US/LC_MESSAGES', 'locale/en_ZA/LC_MESSAGES', 'locale/es_AR/LC_MESSAGES', 'locale/es_BO/LC_MESSAGES', 'locale/es_CA/LC_MESSAGES', 'locale/es_CL/LC_MESSAGES', 'locale/es_CO/LC_MESSAGES', 'locale/es_CR/LC_MESSAGES', 'locale/es_CU/LC_MESSAGES', 'locale/es_DO/LC_MESSAGES', 'locale/es_EC/LC_MESSAGES', 'locale/es_GQ/LC_MESSAGES', 'locale/es_GT/LC_MESSAGES', 'locale/es_HN/LC_MESSAGES', 'locale/es_MX/LC_MESSAGES', 'locale/es_NI/LC_MESSAGES', 'locale/es_PA/LC_MESSAGES', 'locale/es_PE/LC_MESSAGES', 'locale/es_PR/LC_MESSAGES', 'locale/es_PY/LC_MESSAGES', 'locale/es_SV/LC_MESSAGES', 'locale/es_US/LC_MESSAGES', 'locale/es_UY/LC_MESSAGES', 'locale/es_VE/LC_MESSAGES']

# Ensuite on crée les répertoires (si les répertoires intermédiaires 
# n'existent pas, ils sont crées --aussi-- à la volée)
for repNation_EN_ES in ChemSymbLang_EN_ES:
	# Si tous les répertoires existent déjà
	# il ne se passe rien ...
	if os.path.exists(repNation_EN_ES):
		pass
	# Autrement ils sont crées ...
	else: os.makedirs(repNation_EN_ES, 0755)
	
# Liste récupérant les chemins sous la forme: locale/en_CA (Canada) et en excluant du lot: locale/en_EN
contenu_locale_EN = [enX for enX in glob.glob('locale/*') if enX[:-3] == 'locale/en' and enX != 'locale/en_EN']
# Liste récupérant les chemins sous la forme: locale/es_CU (Cuba) et en excluant du lot: locale/es_ES
contenu_locale_ES = [esX for esX in glob.glob('locale/*') if esX[:-3] == 'locale/es' and esX != 'locale/es_ES']

# On vérifie si les fichiers ekd.mo et ekdDoc.mo sont déjà présents dans
# les différents répertoires en_..., si c'est le cas ils sont éliminés.
# Ensuite les fichiers .mo sont copiés dans chaque répertoire de langue
# anglaise
for parcEN in contenu_locale_EN:
	parc_EN = parcEN + '/' + 'LC_MESSAGES/'
	if 'ekd.mo' in os.listdir(parc_EN):
		os.remove(parc_EN+'ekd.mo')
	shutil.copy('locale/en_EN/LC_MESSAGES/ekd.mo', parc_EN)
	if 'ekdDoc.mo' in os.listdir(parc_EN):
		os.remove(parc_EN+'ekdDoc.mo')
	shutil.copy('locale/en_EN/LC_MESSAGES/ekdDoc.mo', parc_EN)

# Même chose qu'au dessus mais pour la langue espagnole
for parcES in contenu_locale_ES:
	parc_ES = parcES + '/' + 'LC_MESSAGES/'
	if 'ekd.mo' in os.listdir(parc_ES):
		os.remove(parc_ES+'ekd.mo')
	shutil.copy('locale/es_ES/LC_MESSAGES/ekd.mo', parc_ES)
	if 'ekdDoc.mo' in os.listdir(parc_ES):
		os.remove(parc_ES+'ekdDoc.mo')
	shutil.copy('locale/es_ES/LC_MESSAGES/ekdDoc.mo', parc_ES)
